summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--menus.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/menus.c b/menus.c
index cf3aabb..e6d3776 100644
--- a/menus.c
+++ b/menus.c
@@ -200,7 +200,7 @@ int Submenu_extra_fine; /* is the extra-fine mode on? */
static int Menu_Is_Item_Visible(int LCD_entry);
static void Menu_Move_Pointer(int move_amount);
static void Display_Number_on_LCD(int Is_Item_Visible,int LCD_row,int LCD_col,char *start_string,int Show_What, int significant_digits, int width_of_column);
-static void Submenu_Display(int redraw);
+static void Submenu_Display(int change_selection);
static void Submenu_Move_Pointer(void);
static int Submenu_Mult_Value(float mult_by);
static void Submenu_Service_Encoder(int encoder_change);
@@ -1240,7 +1240,7 @@ static void Display_Number_on_LCD(int Is_Item_Visible,int LCD_row,int LCD_col,ch
}
-static void Submenu_Display(int redraw)
+static void Submenu_Display(int change_selection)
{
gchar *title = NULL;
int i;
@@ -1250,7 +1250,7 @@ static void Submenu_Display(int redraw)
if ( (globals.MenuStatus.Type_Of_Menu != Submenu_On) ||
(globals.MenuStatus.Error_Screen == YES) ||
(globals.MenuStatus.Nonstd_Display == YES) ||
- (!redraw)) {
+ (!change_selection)) {
LCD_clear();
}
@@ -2044,19 +2044,19 @@ static void Submenu_Display(int redraw)
}
}
- /* If redraw==NO, the submenu is being drawn from scratch. In this case, the arrow pointer points at the
- current operating mode. If redraw=YES, the submenu is being redrawn to scroll the mode list. In this case,
+ /* If change_selection==NO, the submenu is being drawn from scratch. In this case, the arrow pointer points at the
+ current operating mode. If change_selection=YES, the submenu is being redrawn to scroll the mode list. In this case,
the arrow pointer points at the current selection. */
- if (redraw==NO && current_operating_mode<4) {
+ if (change_selection==NO && current_operating_mode<4) {
base_entry=0;
Submenu_Selected_Item=current_operating_mode;
- } else if (redraw==NO) {
+ } else if (change_selection==NO) {
base_entry=current_operating_mode-3;
Submenu_Selected_Item=current_operating_mode;
- } else if (redraw=YES && Submenu_Selected_Item<4) {
+ } else if (change_selection=YES && Submenu_Selected_Item<4) {
base_entry=0;
- } else if (redraw=YES && Submenu_Selected_Item>=4) {
+ } else if (change_selection=YES && Submenu_Selected_Item>=4) {
base_entry=Submenu_Selected_Item-3;
}